@@ -1,10 +1,15 @@
+from unittest.case import skipIf
+
 import requests
 
 from integration.helpers.base_test import BaseTest
 from integration.helpers.deployer.utils.retry import retry
 from integration.helpers.exception import StatusCodeError
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import COGNITO
 
 
+@skipIf(current_region_does_not_support([COGNITO]), "Cognito is not supported in this testing region")
 class TestApiWithAuthorizers(BaseTest):
     def test_authorizers_min(self):
         self.create_and_verify_stack("combination/api_with_authorizers_min")
